@@ -33,11 +33,19 @@ class DocumentList {
 	public:
 	Container& getDocs ();
 	int size () {return docs_.size();}
-	bool docExists (Glib::ustring const &name);
 	Document* newDocWithFile (Glib::ustring const &filename);
 	Document* newDocWithName (Glib::ustring const &key);
 	Document* newDocUnnamed ();
-	Glib::ustring uniqueKey (Glib::ustring const &basename);
+
+	bool docExists (
+		Glib::ustring const &name,
+		Document const *exclusion);
+	Glib::ustring uniqueKey (
+		Glib::ustring const &basename);
+	Glib::ustring uniqueKey (
+		Glib::ustring const &basename,
+		Document const *exclusion);
+
 	void removeDoc (Document* const addr);
 	void loadDoc (
 		Glib::ustring const &filename,
@@ -48,7 +56,7 @@ class DocumentList {
 		BibData const &bib);
 	void print ();
 	void clearTag (int uid);
-	void writeXML (std::ostringstream& out);
+	void writeXML (Glib::ustring &out);
 	void clear () {docs_.clear ();}
 
 	int importFromFile (Glib::ustring const &filename, BibUtils::Format format);
