@@ -22,6 +22,14 @@
 #include <libglademm.h>
 #include <libgnomevfsmm.h>
 
+#include "ucompose.hpp"
+#define DEBUG(x) Utility::debug(__PRETTY_FUNCTION__, x)
+#define DEBUG1(x,a) Utility::debug(__PRETTY_FUNCTION__, String::ucompose(x,a))
+#define DEBUG2(x,a,b) Utility::debug(__PRETTY_FUNCTION__, String::ucompose(x,a,b))
+#define DEBUG3(x,a,b,c) Utility::debug(__PRETTY_FUNCTION__, String::ucompose(x,a,b,c))
+#define DEBUG4(x,a,b,c,d) Utility::debug(__PRETTY_FUNCTION__, String::ucompose(x,a,b,c,d))
+#define DEBUG5(x,a,b,c,d,e) Utility::debug(__PRETTY_FUNCTION__, String::ucompose(x,a,b,c,d,e))
+
 namespace Utility {
 	typedef std::pair <Glib::ustring, Glib::ustring> StringPair;
 
@@ -53,9 +61,6 @@ namespace Utility {
 		Glib::ustring const &filename,
 		Glib::ustring const &extension);
 
-	Glib::RefPtr<Gnome::Glade::Xml> openGlade (
-		Glib::ustring const &filename);
-
 	Glib::ustring findDataFile (
 		Glib::ustring const &filename);
 
@@ -105,6 +110,9 @@ namespace Utility {
 		
 	Glib::ustring mozUrlSelectionToUTF8 (
 		Gtk::SelectionData const &sel);
+
+	Glib::ustring trimWhiteSpace (Glib::ustring const &str);
+	void debug (Glib::ustring tag, Glib::ustring msg);
 }
 
 class TextDialog : public Gtk::Dialog
