@@ -34,6 +34,9 @@ Glib::ustring referencer_ui =
 		"    <menu action='ViewMenu'>"
 		"      <menuitem action='UseIconView'/>"
 		"      <menuitem action='UseListView'/>"
+		"      <menu action='ViewMenuSort' name='ViewMenuSort'>"
+		"        <placeholder name='ViewMenuSortItems'/>"
+		"      </menu>"
 		"      <separator/>"
 		"      <menuitem action='ShowTagPane'/>"
 		"	   <menuitem action='ShowNotesPane'/>"
@@ -53,6 +56,7 @@ Glib::ustring referencer_ui =
 		"      <menuitem action='AddDocFolder'/>"
 		"      <menuitem action='AddDocDoi'/>"
 		"      <menuitem action='AddDocUnnamed'/>"
+//		"      <menuitem action='LibraryFolder'/>"
 		"      <separator/>"
 		"      <menuitem action='OpenDoc'/>"
 		"      <menuitem action='DocProperties'/>"
